{% extends "base.html" %}
{% load i18n %}

{% block title %}{% trans "Create booking" %}{% endblock %}

{% block main %}
    <h1>{% trans "Create booking" %}</h1>
    <form method="post" action=".">
        {% csrf_token %}
        {{ form.as_p }}
        <input type="submit" value="{% trans "Save" %}" />
    </form>
{% endblock %}
